Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Returns a map consisting of the elements mapped by the given `keySelector`. The value
 * can optionally be transformed into another value by specifying a `valueTransformer`.
 *
 * @param {(value: T) => K} keySelector
 * @param {(value: T) => V} valueTransform
 * @returns {Map<K, T | V>}
 */
function associateBy(keySelector, valueTransform) {
    var result = new Map();
    var transform = valueTransform != null
        ? valueTransform
        : function (value) { return value; };
    while (this.iterator.hasNext()) {
        var item = this.iterator.next();
        var key = keySelector(item);
        var value = transform(item);
        result.set(key, value);
    }
    return result;
}
exports.default = associateBy;
//# sourceMappingURL=associateBy.js.map